@@ -1,9 +1,9 @@
-package Dist::Zilla::Plugin::TestMLIncluder;
-$Dist::Zilla::Plugin::TestMLIncluder::VERSION = '0.01';
-use Moose;
-
 # ABSTRACT: Ship your TestML version
 
+package Dist::Zilla::Plugin::TestMLIncluder;
+$Dist::Zilla::Plugin::TestMLIncluder::VERSION = '0.02';
+use Moose;
+
 extends 'Dist::Zilla::Plugin::ModuleIncluder';
 
 has module => (
@@ -50,15 +50,17 @@ has blacklist => (
 
 sub gather_files {
   my $self = shift;
-  my $pegex = '../pegex-pm';
-  my $testml = '../testml-pm';
-  if (
-    -d "$pegex/.git" and
-    -d "$testml/.git"
-  ) {
-    eval "use lib '$pegex/lib', '$testml/lib'; 1" or die $@;
-    $self->SUPER::gather_files(@_);
-    return;
+  for my $prefix (qw(.. ../..)) {
+    my $pegex = "$prefix/pegex-pm";
+    my $testml = "$prefix/testml-pm";
+    if (
+        -d "$pegex/.git" and
+        -d "$testml/.git"
+    ) {
+        eval "use lib '$pegex/lib', '$testml/lib'; 1" or die $@;
+        $self->SUPER::gather_files(@_);
+        return;
+    }
   }
   die "Pegex and TestML repos missing or not in right state";
 }
@@ -68,35 +70,3 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-Dist::Zilla::Plugin::TestMLIncluder - Ship your TestML version
-
-=head1 SYNOPSIS
-
-In dist.ini:
-
-   [TestMLIncluder]
-
-=head1 DESCRIPTION
-
-This module includes the version of TestML on your system with your module
-dist.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2014. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
